.. :changelog:

History
-------

0.1.7 (2015-09-08)
++++++++++++++++++

* Added notification service
* Added inline documentation
* Small refactorings

0.1.6 (2015-09-07)
++++++++++++++++++

* Added online service registration
* Fixed minor issues

0.1.5 (2015-08-19)
++++++++++++++++++

* Fixed minor issues

0.1.4 (2015-08-19)
++++++++++++++++++

* Fixed packaging issue

0.1.3 (2015-08-19)
++++++++++++++++++

* Temporarily fixing piprot issue with pytz

0.1.2 (2015-08-19)
++++++++++++++++++

* Added package requirements

0.1.1 (2015-08-19)
++++++++++++++++++

* Switched to `pip.get_installed_distributions` to get a package list
* minor documentation tweaks

0.1.0 (2015-08-19)
++++++++++++++++++

* First release on PyPI.
